@@ -38,8 +38,11 @@ extern void fnotclasse_more_derivs(void *, void *, void *, void *, void *, void
 extern void fclasse_geosse_equivalent_derivs(void *, void *, void *, void *, void *, void *);
 extern void fnotclasse_derivs(void *, void *, void *, void *, void *, void *);
 extern void misse_derivs(void *, void *, void *, void *, void *, void *);
+extern void misse_strat_derivs(void *, void *, void *, void *, void *, void *);
 extern void maddison_DE_fbisse(void *, void *, void *, void *, void *, void *);
+extern void maddison_DE_strat_fbisse(void *, void *, void *, void *, void *, void *);
 extern void maddison_DE_fhisse(void *, void *, void *, void *, void *, void *);
+extern void maddison_DE_strat_fhisse(void *, void *, void *, void *, void *, void *);
 
 extern void set_birth_bisse_void(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void set_birth_hisse_null_void(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
@@ -76,8 +79,11 @@ static const R_CMethodDef CEntries[] = {
     {"fclasse_geosse_equivalent_derivs",(DL_FUNC) &fclasse_geosse_equivalent_derivs,6},
     {"fnotclasse_derivs",               (DL_FUNC) &fnotclasse_derivs,               6},
     {"misse_derivs",                    (DL_FUNC) &misse_derivs,                    6},
+    {"misse_strat_derivs",              (DL_FUNC) &misse_strat_derivs,              6},
     {"maddison_DE_fbisse",              (DL_FUNC) &maddison_DE_fbisse,              6},
+    {"maddison_DE_strat_fbisse",        (DL_FUNC) &maddison_DE_strat_fbisse,        6},
     {"maddison_DE_fhisse",              (DL_FUNC) &maddison_DE_fhisse,              6},
+    {"maddison_DE_strat_fhisse",        (DL_FUNC) &maddison_DE_strat_fhisse,        6},
     {"set_birth_bisse_void",            (DL_FUNC) &set_birth_bisse_void,           29},
     {"set_birth_hisse_null_void",       (DL_FUNC) &set_birth_hisse_null_void,      54},
     {"set_birth_hisse_void",            (DL_FUNC) &set_birth_hisse_void,           59},
